@@ -1,10 +1,11 @@
+from __future__ import annotations
+
 import json
 from collections.abc import Callable
-from typing import Any, Literal, cast, List, Tuple, Dict, Union
+from typing import TYPE_CHECKING, Any, Dict, List, Literal, Tuple, Union, cast
 
 from rsb.adapters.adapter import Adapter
 
-from agentle.agents.agent import Agent
 from agentle.agents.knowledge.static_knowledge import StaticKnowledge
 from agentle.generations.models.message_parts.file import FilePart
 from agentle.generations.models.message_parts.text import TextPart
@@ -12,6 +13,12 @@ from agentle.generations.models.message_parts.tool_execution_suggestion import (
     ToolExecutionSuggestion,
 )
 from agentle.generations.models.messages.user_message import UserMessage
+from agentle.generations.tools.tool import Tool
+from agentle.generations.tools.tool_execution_result import ToolExecutionResult
+
+if TYPE_CHECKING:
+    from agentle.agents.agent import Agent
+
 
 # Define a type for session-added knowledge items for clarity
 SessionKnowledgeItem = Dict[
@@ -19,7 +26,7 @@ SessionKnowledgeItem = Dict[
 ]  # Keys: "type", "name", "content", "data_bytes", "mime_type"
 
 
-class AgentToStreamlit(Adapter[Agent, "Callable[[], None]"]):
+class AgentToStreamlit[T = None](Adapter["Agent[T]", "Callable[[], None]"]):
     title: str | None
     description: str | None
     initial_mode: Literal["dev", "presentation"]
@@ -34,7 +41,7 @@ class AgentToStreamlit(Adapter[Agent, "Callable[[], None]"]):
         self.description = description
         self.initial_mode = initial_mode
 
-    def adapt(self, _f: Agent) -> Callable[[], None]:
+    def adapt(self, _f: "Agent[T]") -> Callable[[], None]:
         """
         Creates a Streamlit app that provides a chat interface to interact with the agent.
 
@@ -59,12 +66,12 @@ class AgentToStreamlit(Adapter[Agent, "Callable[[], None]"]):
         Example:
             ```python
             from agentle.agents.agent import Agent
-            from agentle.generations.providers.google.google_genai_generation_provider import GoogleGenaiGenerationProvider
+            from agentle.generations.providers.google.google_generation_provider import GoogleGenerationProvider
 
             # Create an agent
             agent = Agent(
-                generation_provider=GoogleGenaiGenerationProvider(),
-                model="gemini-2.0-flash",
+                generation_provider=GoogleGenerationProvider(),
+                model="gemini-2.5-flash",
                 instructions="You are a helpful assistant."
             )
 
@@ -74,6 +81,7 @@ class AgentToStreamlit(Adapter[Agent, "Callable[[], None]"]):
             # Save this as app.py and run with: streamlit run app.py
             ```
         """
+
         agent = _f
         app_title = self.title or f"{agent.name} Agent"
         app_description = self.description or (
@@ -469,7 +477,7 @@ class AgentToStreamlit(Adapter[Agent, "Callable[[], None]"]):
                                     "mime_type": "text/plain",
                                 }
                             )
-                            st.success(f"Added text/URL snippet to session knowledge.")
+                            st.success("Added text/URL snippet to session knowledge.")
                             st.session_state.new_knowledge_text_url_input = ""
                             added_something = True
                         if new_knowledge_file is not None:
@@ -835,9 +843,13 @@ class AgentToStreamlit(Adapter[Agent, "Callable[[], None]"]):
 
                 # Agent Processing
                 with st.spinner("🤖 Agent is thinking..."):
-                    agent_input_parts: List[Union[TextPart, FilePart]] = [
-                        TextPart(text=user_prompt)
-                    ]
+                    agent_input_parts: List[
+                        TextPart
+                        | FilePart
+                        | Tool[Any]
+                        | ToolExecutionSuggestion
+                        | ToolExecutionResult
+                    ] = [TextPart(text=user_prompt)]
 
                     files_to_process_agent = new_user_message_metadata.get("files")
                     if isinstance(files_to_process_agent, list):
@@ -876,10 +888,13 @@ class AgentToStreamlit(Adapter[Agent, "Callable[[], None]"]):
                             new_instructions=final_instructions_for_run
                         )
 
-                        with temp_agent_for_run.with_mcp_servers():
+                        with temp_agent_for_run.start_mcp_servers():
                             result = temp_agent_for_run.run(final_agent_input)
 
                         generation = result.generation
+                        if generation is None:
+                            st.error("No generation found")
+                            return
                         response_text = generation.text or "..."
 
                         response_metadata_agent: Dict[str, Any] = {}
