@@ -14,6 +14,7 @@ and normalizes them to Agentle's internal representation.
 The adapter supports structured output parsing for type-safe responses through its
 generic type parameter.
 """
+
 from __future__ import annotations
 import datetime
 import uuid
@@ -59,7 +60,6 @@ class CerebrasCompletionToGenerationAdapter[T](
     """
 
     response_schema: type[T] | None
-    start_time: datetime.datetime
     model: str
     message_to_generated_assistant_message_adapter: (
         CerebrasMessageToGeneratedAssistantMessageAdapter[T]
@@ -70,7 +70,6 @@ class CerebrasCompletionToGenerationAdapter[T](
         self,
         *,
         response_schema: type[T] | None = None,
-        start_time: datetime.datetime,
         model: str,
         message_to_generated_assistant_message_adapter: CerebrasMessageToGeneratedAssistantMessageAdapter[
             T
@@ -92,7 +91,6 @@ class CerebrasCompletionToGenerationAdapter[T](
         """
         self.response_schema = response_schema
         self.model = model
-        self.start_time = start_time
         self.message_to_generated_assistant_message_adapter = (
             message_to_generated_assistant_message_adapter
             or CerebrasMessageToGeneratedAssistantMessageAdapter(
@@ -133,7 +131,6 @@ class CerebrasCompletionToGenerationAdapter[T](
         )
 
         return Generation(
-            elapsed_time=datetime.datetime.now() - self.start_time,
             id=self.preferred_id or uuid.uuid4(),
             choices=choices,
             object="chat.generation",
