@@ -1,7 +1,7 @@
 from __future__ import annotations
 
 import asyncio
-from collections.abc import Mapping
+from collections.abc import AsyncGenerator, Mapping
 from typing import TYPE_CHECKING, Any, Sequence, cast, override
 
 from agentle.generations.models.generation.generation import Generation
@@ -11,6 +11,7 @@ from agentle.generations.models.generation.generation_config_dict import (
 )
 from agentle.generations.models.messages.assistant_message import AssistantMessage
 from agentle.generations.models.messages.developer_message import DeveloperMessage
+from agentle.generations.models.messages.message import Message
 from agentle.generations.models.messages.user_message import UserMessage
 from agentle.generations.providers.base.generation_provider import GenerationProvider
 from agentle.generations.providers.ollama.adapters.chat_response_to_generation_adapter import (
@@ -31,6 +32,8 @@ if TYPE_CHECKING:
 
     from agentle.generations.tracing.otel_client import OtelClient
 
+type WithoutStructuredOutput = None
+
 
 class OllamaGenerationProvider(GenerationProvider):
     def __init__(
@@ -58,6 +61,21 @@ class OllamaGenerationProvider(GenerationProvider):
     def organization(self) -> str:
         return "Ollama"
 
+    @override
+    async def stream_async[T = WithoutStructuredOutput](
+        self,
+        *,
+        model: str | ModelKind | None = None,
+        messages: Sequence[Message],
+        response_schema: type[T] | None = None,
+        generation_config: GenerationConfig | GenerationConfigDict | None = None,
+        tools: Sequence[Tool] | None = None,
+    ) -> AsyncGenerator[Generation[WithoutStructuredOutput], None]:
+        # Not implemented yet; declare as async generator to satisfy type checkers
+        raise NotImplementedError("This method is not implemented yet.")
+        if False:  # pragma: no cover
+            yield cast(Generation[WithoutStructuredOutput], None)
+
     @observe
     @override
     async def generate_async[T](
@@ -73,7 +91,7 @@ class OllamaGenerationProvider(GenerationProvider):
 
         tool_adapter = ToolToOllamaToolAdapter()
 
-        bm = cast(BaseModel, response_schema) if response_schema else None
+        bm = cast(BaseModel, response_schema) if response_schema else None  # type: ignore
 
         _generation_config = self._normalize_generation_config(generation_config)
 
