@@ -43,7 +43,7 @@ class ToolExecutionResult(BaseModel):
 
     def __str__(self) -> str:
         return dedent(f"""\
-        <sugestion>
+        <suggestion>
         {self.suggestion}
         </suggestion>
         <result>
