@@ -23,10 +23,10 @@ def file_parser_default_factory(
     from agentle.parsing.parsers.file_parser import FileParser
 
     return FileParser(
-        visual_description_agent=visual_description_agent_default_factory(
+        visual_description_provider=visual_description_agent_default_factory(
             provider=visual_description_provider
         ),
-        audio_description_agent=audio_description_agent_default_factory(
+        visual_description_provider=audio_description_agent_default_factory(
             provider=audio_description_provider
         ),
         parse_timeout=parse_timeout,
