@@ -9,20 +9,20 @@ using visual description agents, and organize them as sequential sections.
 import io
 from collections.abc import MutableSequence
 from pathlib import Path
-from typing import Literal, override
+from typing import Literal
 
 from rsb.functions.bytes2mime import bytes2mime
+
 from rsb.models.field import Field
 
-from agentle.agents.agent import Agent
+
 from agentle.generations.models.message_parts.file import FilePart
 from agentle.generations.models.structured_outputs_store.visual_media_description import (
     VisualMediaDescription,
 )
+
+from agentle.generations.providers.base.generation_provider import GenerationProvider
 from agentle.parsing.document_parser import DocumentParser
-from agentle.parsing.factories.visual_description_agent_default_factory import (
-    visual_description_agent_default_factory,
-)
 from agentle.parsing.image import Image
 from agentle.parsing.parsed_file import ParsedFile
 from agentle.parsing.section_content import SectionContent
@@ -99,15 +99,12 @@ class GifFileParser(DocumentParser):
 
     type: Literal["gif"] = "gif"
 
-    visual_description_agent: Agent[VisualMediaDescription] = Field(
-        default_factory=visual_description_agent_default_factory,
-    )
+    visual_description_agent: GenerationProvider = Field(...)
     """
     The agent to use for generating the visual description of the document.
     Useful when you want to customize the prompt for the visual description.
     """
 
-    @override
     async def parse_async(
         self,
         document_path: str,
@@ -211,13 +208,16 @@ class GifFileParser(DocumentParser):
             frame_image_ocr: str | None = None
             # If strategy is HIGH, pass the frame to the agent
             text_description = ""
+
             if self.visual_description_agent:
                 agent_input = FilePart(
                     mime_type=bytes2mime(png_bytes),
                     data=png_bytes,
                 )
-                agent_response = await self.visual_description_agent.run_async(
-                    agent_input
+                agent_response = await self.visual_description_agent.generate_by_prompt_async(
+                    agent_input,
+                    developer_prompt="You are a helpful assistant that deeply understands visual media.",
+                    response_schema=VisualMediaDescription,
                 )
                 frame_image_ocr = agent_response.parsed.ocr_text
                 text_description = agent_response.parsed.md
