@@ -6,9 +6,10 @@ structured representations. It can decompress and extract the XML content from P
 files, making the network topology and configuration data accessible.
 """
 
+import os
 import tempfile
 from pathlib import Path
-from typing import Literal, override
+from typing import Literal
 
 from agentle.parsing.document_parser import DocumentParser
 from agentle.parsing.parsed_file import ParsedFile
@@ -63,7 +64,6 @@ class PKTFileParser(DocumentParser):
 
     type: Literal["pkt"] = "pkt"
 
-    @override
     async def parse_async(self, document_path: str) -> ParsedFile:
         """
         Asynchronously parse a Packet Tracer file and extract its XML content.
@@ -103,7 +103,7 @@ class PKTFileParser(DocumentParser):
             cleaned up after the parsing is complete.
         """
         with tempfile.TemporaryDirectory() as temp_dir:
-            file_path = f"{temp_dir}/{document_path}"
+            file_path = os.path.join(temp_dir, document_path)
             # file.save_to_file(file_path)
             # TODO: save the file to the temp directory
             with open(file_path, "wb") as f:
