@@ -7,18 +7,17 @@ from their visual content.
 
 from pathlib import Path
 from typing import Literal
+
 from rsb.functions.ext2mime import ext2mime
+
 from rsb.models.field import Field
 
-from agentle.agents.agent import Agent
 from agentle.generations.models.message_parts.file import FilePart
 from agentle.generations.models.structured_outputs_store.visual_media_description import (
     VisualMediaDescription,
 )
+from agentle.generations.providers.base.generation_provider import GenerationProvider
 from agentle.parsing.document_parser import DocumentParser
-from agentle.parsing.factories.visual_description_agent_default_factory import (
-    visual_description_agent_default_factory,
-)
 from agentle.parsing.parsed_file import ParsedFile
 from agentle.parsing.section_content import SectionContent
 
@@ -75,13 +74,13 @@ class VideoFileParser(DocumentParser):
     ```python
     from agentle.agents.agent import Agent
     from agentle.generations.models.structured_outputs_store.visual_media_description import VisualMediaDescription
-    from agentle.generations.providers.google.google_genai_generation_provider import GoogleGenaiGenerationProvider
+    from agentle.generations.providers.google.google_generation_provider import GoogleGenerationProvider
 
     # Create a custom agent for specialized video analysis
     sports_video_agent = Agent(
         model="gemini-2.0-pro-vision",
         instructions="Analyze sports videos with focus on player movements and game statistics",
-        generation_provider=GoogleGenaiGenerationProvider(),
+        generation_provider=GoogleGenerationProvider(),
         response_schema=VisualMediaDescription
     )
 
@@ -95,9 +94,7 @@ class VideoFileParser(DocumentParser):
 
     type: Literal["video"] = "video"
 
-    visual_description_agent: Agent[VisualMediaDescription] = Field(
-        default_factory=visual_description_agent_default_factory,
-    )
+    visual_description_agent: GenerationProvider = Field(...)
     """
     The agent to use for generating the visual description of the document.
     Useful when you want to customize the prompt for the visual description.
@@ -139,8 +136,10 @@ class VideoFileParser(DocumentParser):
             raise ValueError("VideoFileParser only supports .mp4 files.")
 
         file_contents = path.read_bytes()
-        visual_media_description = await self.visual_description_agent.run_async(
-            FilePart(data=file_contents, mime_type=ext2mime(extension))
+        visual_media_description = await self.visual_description_agent.generate_by_prompt_async(
+            FilePart(data=file_contents, mime_type=ext2mime(extension)),
+            developer_prompt="You are a helpful assistant that deeply understands visual media.",
+            response_schema=VisualMediaDescription,
         )
 
         return ParsedFile(
