@@ -7,12 +7,13 @@ A pipeline is a sequence of agents where the output from one agent becomes the i
 
 from agentle.agents.agent import Agent
 from agentle.agents.agent_pipeline import AgentPipeline
-from agentle.generations.providers.google.google_genai_generation_provider import (
-    GoogleGenaiGenerationProvider,
+from agentle.generations.providers.google.google_generation_provider import (
+    GoogleGenerationProvider,
 )
 
+
 # Create a common provider for all agents
-provider = GoogleGenaiGenerationProvider()
+provider = GoogleGenerationProvider()
 
 # Step 1: Create specialized agents for each stage of the pipeline
 
@@ -20,7 +21,7 @@ provider = GoogleGenaiGenerationProvider()
 research_agent = Agent(
     name="Research Agent",
     generation_provider=provider,
-    model="gemini-2.0-flash",
+    model="gemini-2.5-flash",
     instructions="""You are a research agent focused on gathering accurate information.
     Your task is to collect relevant facts and data on the given topic.
     Be thorough and prioritize accuracy over speculation.
@@ -32,7 +33,7 @@ research_agent = Agent(
 analysis_agent = Agent(
     name="Analysis Agent",
     generation_provider=provider,
-    model="gemini-2.0-flash",
+    model="gemini-2.5-flash",
     instructions="""You are an analysis agent that processes information and identifies patterns.
     You will receive research data and your task is to:
     1. Identify key themes and patterns
@@ -46,7 +47,7 @@ analysis_agent = Agent(
 summary_agent = Agent(
     name="Summary Agent",
     generation_provider=provider,
-    model="gemini-2.0-flash",
+    model="gemini-2.5-flash",
     instructions="""You are a summary agent that creates concise, well-structured summaries.
     Your task is to take the analysis you receive and create a clear, reader-friendly summary that:
     1. Presents key findings in a logical order
