@@ -1,12 +1,11 @@
+from dotenv import load_dotenv
 from agentle.generations.providers.cerebras.cerebras_generation_provider import (
     CerebrasGenerationProvider,
 )
-from agentle.generations.tracing.langfuse import LangfuseObservabilityClient
 
+load_dotenv()
 
-tracing_client = LangfuseObservabilityClient()
-
-provider = CerebrasGenerationProvider(tracing_client=tracing_client)
+provider = CerebrasGenerationProvider()
 
 generation = provider.generate_by_prompt(
     prompt="Hello, world!",
